import javax.naming.*;
import javax.naming.directory.*;

import java.util.Hashtable;

/**
  * Demonstrates how to bind a Referenceable object to a context
  * using a different encoding character.
  *
  * Need schema checking to be turned off on server (unless you add
  * a fruit objectclass to the schema).
  *
  * usage: java RefObj
  */

class RefObj {
    public static void main(String[] args) {

	// Set up environment for creating initial context
	Hashtable env = new Hashtable(11);
	env.put(Context.INITIAL_CONTEXT_FACTORY, 
	    "com.sun.jndi.ldap.LdapCtxFactory");
	env.put(Context.PROVIDER_URL, "ldap://localhost:389/o=JNDITutorial");

	// Ask to use ':' as the encoding character
	env.put("java.naming.ldap.ref.separator", ":");

	try {
	    // Create the initial context
	    DirContext ctx = new InitialDirContext(env);

	    // Create object to be bound
	    Fruit fruit = new Fruit("orange");

	    // Perform bind
	    ctx.rebind("cn=favorite", fruit);

	    // Read object back
	    Fruit f2 = (Fruit) ctx.lookup("cn=favorite");
	    System.out.println(f2);

	    // Read attributes to see encoding
	    Attributes attrs = ctx.getAttributes("cn=favorite");
	    System.out.println(attrs);

	} catch (NamingException e) {
	    System.out.println("Operation failed: " + e);
	}
    }
}
